package org.tranql.connector;

import java.util.Iterator;
import java.util.Set;
import java.util.Arrays;

import javax.resource.spi.ConnectionRequestInfo;
import javax.resource.spi.ResourceAdapterInternalException;
import javax.resource.spi.security.PasswordCredential;
import javax.security.auth.Subject;

/**
 *
 *
 * @version $Revision: 93 $ $Date: 2004-06-14 19:35:58 -0400 (Mon, 14 Jun 2004) $
 *
 * */
public class CredentialExtractor {

    private final String userName;
    private final String password;

    public CredentialExtractor(Subject subject, ConnectionRequestInfo connectionRequestInfo, UserPasswordManagedConnectionFactory managedConnectionFactory) throws ResourceAdapterInternalException {
        assert managedConnectionFactory != null;

        if (connectionRequestInfo != null && !(connectionRequestInfo instanceof UserPasswordHandleFactoryRequestInfo)) {
            throw new ResourceAdapterInternalException("ConnectionRequestInfo must be a UserPasswordHandleFactoryRequestInfo, not a " + connectionRequestInfo.getClass().getName());
        }
        if (subject != null) {
            Set credentials = subject.getPrivateCredentials(PasswordCredential.class);
            for (Iterator creds = credentials.iterator(); creds.hasNext();) {
                PasswordCredential passwordCredential = (PasswordCredential) creds.next();
                if (managedConnectionFactory.equals(passwordCredential.getManagedConnectionFactory())) {
                    userName = passwordCredential.getUserName();
                    password = new String(passwordCredential.getPassword());
                    return;
                }
            }
            throw new ResourceAdapterInternalException("No credential found for this ManagedConnectionFactory: " + managedConnectionFactory);
        }
        if (connectionRequestInfo != null
                && ((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getUser() != null) {
            userName = ((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getUser();
            password = ((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getPassword();
            return;
        }
        userName = managedConnectionFactory.getUserName();
        password = managedConnectionFactory.getPassword();
    }

    public boolean matches(Subject subject, ConnectionRequestInfo connectionRequestInfo, UserPasswordManagedConnectionFactory managedConnectionFactory) throws ResourceAdapterInternalException {
        assert managedConnectionFactory != null;

        if (connectionRequestInfo != null && !(connectionRequestInfo instanceof UserPasswordHandleFactoryRequestInfo)) {
            throw new ResourceAdapterInternalException("ConnectionRequestInfo must be a UserPasswordHandleFactoryRequestInfo, not a " + connectionRequestInfo.getClass().getName());
        }
        if (subject != null) {
            Set credentials = subject.getPrivateCredentials(PasswordCredential.class);
            for (Iterator creds = credentials.iterator(); creds.hasNext();) {
                PasswordCredential passwordCredential = (PasswordCredential) creds.next();
                if (managedConnectionFactory.equals(passwordCredential.getManagedConnectionFactory())) {
                    return (userName == null ? passwordCredential.getUserName() == null : userName.equals(passwordCredential.getUserName())
                            && (password == null ? passwordCredential.getPassword() == null : Arrays.equals(password.toCharArray(), passwordCredential.getPassword())));
                }
            }
            throw new ResourceAdapterInternalException("No credential found for this ManagedConnectionFactory: " + managedConnectionFactory);
        }
        if (connectionRequestInfo != null
                && ((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getUser() != null) {
            return (userName.equals(((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getUser()))
                    && (password == null ? ((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getPassword() == null : password.equals(((UserPasswordHandleFactoryRequestInfo) connectionRequestInfo).getPassword()));
        }
        return (userName == null ? managedConnectionFactory.getUserName() == null : userName.equals(managedConnectionFactory.getUserName())
                && (password == null ? managedConnectionFactory.getPassword() == null : password.equals(managedConnectionFactory.getPassword())));
    }

    public String getUserName() {
        return userName;
    }

    public String getPassword() {
        return password;
    }
}
